package Net::Prober::http;
{
  $Net::Prober::http::VERSION = '0.14';
}

use strict;
use warnings;
use base 'Net::Prober::Probe::HTTP';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Net::Prober::http

=head1 VERSION

version 0.14

=head1 AUTHOR

Cosimo Streppone <cosimo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Cosimo Streppone.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
